@@ -81,6 +81,15 @@ def get_payload(token: str, safe: bool = True) -> Dict[str, Any]:
     )
 
 
+def get_expired_payload(token: str) -> Dict[str, Any]:
+    return jwt.decode(
+        token,
+        read_key_from_env("PUBLIC_KEY"),
+        algorithms=["RS256"],
+        options={"verify_exp": False},
+)
+
+
 def nanoid_algorithm(random_bytes: int) -> bytearray:
     """From https://github.com/puyuan/py-nanoid"""
     return bytearray(os.urandom(random_bytes))
@@ -119,4 +128,7 @@ def generate_token(token_info: dict, exp_min: int):
 
 
 def get_admin_token():
-    return generate_token(token_info={"sub": "ms_auth"}, exp_min=15)
\ No newline at end of file
+    return generate_token(token_info={"sub": "ms_auth"}, exp_min=15)
+
+
+{"sub": "15f45b36-bdfa-4313-9a11-5e07ad6f82f4", }
\ No newline at end of file
