@@ -25,6 +25,8 @@ from tenacity import (
     AsyncRetrying,
 )
 
+AsyncContextManagerCallable = Callable[[], AsyncContextManager[Any]]
+
 try:
     # optionnal dependency
     # if fastapi is installed, then it's better to use their HTTPException
@@ -93,13 +95,14 @@ class CustomAsyncClient:
         should_retry: Optional[Callable] = None,
         retry_policy: Optional[AsyncRetrying] = None,
         should_raise_error_as_httpexception: Optional[Callable] = None,
+        should_alert_sentry: Optional[Callable] = None,
         event_hooks: Dict[str, Sequence[Callable]] = None,
         *args: Any,
         **kwargs: Any,
     ) -> None:
         self.timeout = timeout
         self.raise_if_4xx_5xx = raise_if_4xx_5xx
-        self.client: AsyncContextManager = lambda: self.get_client(*args, **kwargs)
+        self.client: AsyncContextManagerCallable = lambda: self.get_client(*args, **kwargs)
         self.should_retry = default_should_retry if should_retry is None else should_retry
         self.retry_policy = default_retrier if retry_policy is None else retry_policy
         self.event_hooks = default_event_hooks if event_hooks is None else event_hooks
@@ -107,6 +110,10 @@ class CustomAsyncClient:
             self.should_raise_error_as_httpexception = lambda e: True
         else:
             self.should_raise_error_as_httpexception = should_raise_error_as_httpexception
+        if should_alert_sentry is None:
+            self.should_alert_sentry = lambda e: True
+        else:
+            self.should_alert_sentry = should_alert_sentry
 
     @contextlib.asynccontextmanager
     async def get_client(self, *args: Any, **kwargs: Any) -> AsyncIterator:
@@ -125,7 +132,9 @@ class CustomAsyncClient:
                     res = await self.request_with_retry(client, *args, **kwargs)
                 else:
                     res = await self.request_no_retry(client, *args, **kwargs)
-                if self.raise_if_4xx_5xx and int(res.status_code) > 399:  # raise_for_status() raises for 303 redirect
+                if (
+                    self.raise_if_4xx_5xx and int(res.status_code) > 399
+                ):  # raise_for_status() raises for 303 redirect
                     res.raise_for_status()  # HTTPStatusError (inherits HTTPError) if 4xx or 5xx
             except HTTPError as e:
                 self.log_and_raise_exception(e)
@@ -148,7 +157,10 @@ class CustomAsyncClient:
         status_code = e.response.status_code if has_response else 500
         message = e.response.text if has_response else str(e)
         # attempt to use agathe code here
-        event_id = safe_capture_exception(e)
+        if self.should_alert_sentry(e):
+            event_id = safe_capture_exception(e)
+        else:
+            event_id = "no id"
         json_content = {"message": message, "sentry_event_id": event_id}
         if self.should_raise_error_as_httpexception(e):
             raise HTTPException(
@@ -158,30 +170,16 @@ class CustomAsyncClient:
         else:
             raise e
 
-    async def get(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="get", url=url, *new_args, **kwargs)
+    def __getattr__(self, method):
+        if method not in {"get", "post", "put", "patch", "head", "options", "delete"}:
+            raise AttributeError()
 
-    async def post(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="post", url=url, *new_args, **kwargs)
+        async def new_function(*args, **kwargs):
+            kwargs["method"] = method
+            if args:
+                if len(args) > 1:
+                    raise Exception("only one positional argument is authorized")
+                kwargs["url"] = args[0]
+            return await self.request(**kwargs)
 
-    async def put(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="put", url=url, *new_args, **kwargs)
-
-    async def patch(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="put", url=url, *new_args, **kwargs)
-
-    async def head(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="head", url=url, *new_args, **kwargs)
-
-    async def options(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="options", url=url, *new_args, **kwargs)
-
-    async def delete(self, *args, **kwargs):
-        url, *new_args = args
-        return await self.request(method="delete", url=url, *new_args, **kwargs)
+        return new_function
